WaveFormBar constructor

const WaveFormBar({
  1. Key? key,
  2. required Amplitude amplitude,
  3. Animation<double>? animation,
  4. int maxHeight = 2,
  5. Color color = Colors.cyan,
})

Creates a WaveFormBar widget.

amplitude is the amplitude value that determines the height of the bar. animation is an optional animation for the bar. maxHeight is the maximum height multiplier for the bar. Defaults to 2. color is the color of the bar. Defaults to cyan.

Implementation

const WaveFormBar({
  super.key,
  required this.amplitude,
  this.animation,
  this.maxHeight = 2,
  this.color = Colors.cyan,
});